process

package
v1.0.0-beta.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 31, 2019 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanUp

func CleanUp()

CleanUp checks the age of items in the cache and removes if older than 10 days

func Installs

func Installs(installs []string, catalogsMap map[int]map[string]catalog.Item)

Installs prepares and then installs and array of items

func Manifests

func Manifests(manifests []manifest.Item, catalogsMap map[int]map[string]catalog.Item) (installs, uninstalls, updates []string)

Manifests iterates though the first manifest and any included manifests

func Uninstalls

func Uninstalls(uninstalls []string, catalogsMap map[int]map[string]catalog.Item)

Uninstalls prepares and then installs and array of items

func Updates

func Updates(updates []string, catalogsMap map[int]map[string]catalog.Item)

Updates prepares and then installs and array of items

Types

This section is empty.

Jump to