process

package
v1.0.0-alpha.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 2, 2018 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanUp

func CleanUp()

CleanUp checks the age of items in the cache and removes if older than 10 days

func Installs

func Installs(installs []string, catalog map[string]catalog.Item)

Installs prepares and then installs and array of items

func Manifests

func Manifests(manifests []manifest.Item, catalog map[string]catalog.Item) (installs, uninstalls, updates []string)

Manifests iterates though the first manifest and any included manifests

func Uninstalls

func Uninstalls(uninstalls []string, catalog map[string]catalog.Item)

Uninstalls prepares and then installs and array of items

func Updates

func Updates(updates []string, catalog map[string]catalog.Item)

Updates prepares and then installs and array of items

Types

This section is empty.

Jump to